# Pupa: A legislative data scraping framework

![example workflow](https://github.com/opencivicdata/pupa/actions/workflows/package.yml/badge.svg?branch=master)
[![Coverage Status](https://coveralls.io/repos/opencivicdata/pupa/badge.png?branch=master)](https://coveralls.io/r/opencivicdata/pupa?branch=master)
[![PyPI](https://img.shields.io/pypi/v/pupa.svg)](https://pypi.python.org/pypi/pupa)
